@@ -1,4 +1,4 @@
-/* $Id: open.c,v 1.19 2004/06/09 18:52:21 bdejean Exp $ */
+/* $Id: open.c,v 1.20 2005/08/02 09:47:19 bdejean Exp $ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -23,6 +23,7 @@
 
 #include <glibtop.h>
 #include <glibtop/open.h>
+#include <glibtop/init_hooks.h>
 
 /* !!! THIS FUNCTION RUNS SUID ROOT - CHANGE WITH CAUTION !!! */
 
@@ -30,7 +31,7 @@ void
 glibtop_init_p (glibtop *server, const unsigned long features,
 		const unsigned flags)
 {
-	glibtop_init_func_t *init_fkt;
+	const glibtop_init_func_t *init_fkt;
 
 	if (server == NULL)
 		glibtop_error_r (NULL, "glibtop_init_p (server == NULL)");
